@@ -418,11 +418,10 @@ class Scaffold(object):
         lower_model = self.model.lower()
 
         # Check if view already exists
-        print(LIST_VIEW)
-        print(LIST_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
+        
     
         if not self.view_exists(view_path, "%s_list" % lower_model):
-            view_list.append(LIST_VIEW % {'lower_model': lower_model, 'model': self.model})
+            view_list.append(LIST_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
             self._info("added \t%s\t%s_view" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_view" % (view_path, lower_model), 1)
@@ -430,25 +429,25 @@ class Scaffold(object):
 
 
         if not self.view_exists(view_path, "%s_details" % lower_model):
-            view_list.append(DETAILS_VIEW % {'lower_model': lower_model, 'model': self.model})
+            view_list.append(DETAILS_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
             self._info("added \t%s\t%s_details" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_details" % (view_path, lower_model), 1)
 
         if not self.view_exists(view_path, "%s_delete" % lower_model):
-            view_list.append(DELETE_VIEW % {'lower_model': lower_model, 'model': self.model})
+            view_list.append(DELETE_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
             self._info("added \t%s\t%s_delete" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_delete" % (view_path, lower_model), 1)
             
         if not self.view_exists(view_path, "%s_new" % lower_model):
-            view_list.append(CREATE_VIEW % {'lower_model': lower_model, 'model': self.model})
+            view_list.append(CREATE_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
             self._info("added \t%s\t%s_new" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_new" % (view_path, lower_model), 1)
      
         if not self.view_exists(view_path, "%s_edit" % lower_model):
-            view_list.append(EDIT_VIEW % {'lower_model': lower_model, 'model': self.model})
+            view_list.append(EDIT_VIEW.replace('%(lower_model)',lower_model).replace('%(model)',self.model))
             self._info("added \t%s\t%s_edit" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_edit" % (view_path, lower_model), 1)
